@@ -13,7 +13,7 @@ INPUTS_PARAMS_USAGE = (
 )
 WORKFLOW_TO_EXECUTE = "The workflow to execute [default: {0}]"
 
-BLUEPRINT_PATH = "The path to the application's blueprint file [DEPRECATED]"
+BLUEPRINT_PATH = "The path to the application's blueprint file."
 BLUEPRINT_ID = "The unique identifier for the blueprint"
 VALIDATE_BLUEPRINT = "Validate the blueprint first"
 
@@ -86,6 +86,11 @@ SKIP_REINSTALL = (
     "been modified, as part of a deployment update. Node instances that were "
     "explicitly given to the reinstall list will still be reinstalled"
 )
+DONT_SKIP_REINSTALL = (
+    "Reinstall node-instances that their properties have been modified as part"
+    " of a deployment update. Node instances that were explicitly specified"
+    " in the reinstall list will be reinstalled too."
+)
 IGNORE_FAILURE = (
     "Supply the parameter `ignore_failure` with the value `true` to the "
     "uninstall workflow"
@@ -204,7 +209,7 @@ IMPORT_SSH_KEYS = 'WARNING: Import exported keys to their original locations'
 
 SORT_BY = "Key for sorting the list"
 DESCENDING = "Sort list in descending order [default: False]"
-SEARCH = 'Search resources by name/id. The returned list will include only ' \
+SEARCH = 'Search resources by id. The returned list will include only ' \
          'resources that contain the given search pattern'
 
 TENANT = 'The name of the tenant'
@@ -373,17 +378,27 @@ QUEUE_SNAPSHOTS = 'If set, snapshot-creation-workflows that can`t currently ' \
                   'run will be queued and run automatically when possible'
 QUEUE_EXECUTIONS = 'If set, executions that can`t currently run will be '\
                    'queued and run automatically when possible'
-SCHEDULE_EXECUTIONS = 'The time (including timezone) this workflow will be' \
-                      ' executed at; expected format: YYYYMMDDHHMM+HHMM or ' \
-                      'YYYYMMDDHHMM-HHMM. e.g.: 201801182230-0500' \
-                      ' (18th January 2018 10:30pm EST)'
 
-SCHEDULE_FREQUENCY = "Frequency with which to run the execution, e.g. " \
-                     "'2 weeks'"
+TIME_UNITS = 'Supported time units are: min|minute(s)|h|hour(s)|d|day' \
+             '(s)|w|week(s)|mo| month(s)|y|year(s)'
+
+SCHEDULE_EXECUTIONS = 'This option is deprecated; use `cfy deployments ' \
+                      'schedule create` instead. The time (including ' \
+                      'timezone) this workflow will be executed at; ' \
+                      'expected format: YYYYMMDDHHMM+HHMM or ' \
+                      'YYYYMMDDHHMM-HHMM. e.g.: 201801182230-0500 (18th ' \
+                      'January 2018 10:30pm EST)'
+
+SCHEDULE_NAME = "A name for the schedule. If not provided, defaults to " \
+                "{workflow-id}"
+SCHEDULE_RECURRENCE = "Recurrence on the scheduled execution. e.g. " \
+                     "'2 weeks', '30 min' or '1d'. " + TIME_UNITS
 SCHEDULE_COUNT = "Maximum number of times to run the execution. " \
                  "If left empty, there's no limit on repetition"
 SCHEDULE_WEEKDAYS = "Weekdays on which to run the execution, e.g. " \
-                    "'su,mo,tu'. If left empty, will run on any weekday"
+                    "'su,mo,tu'. You can also prefix 1 to 4 or l-, e.g. " \
+                    "'1su, l-fr' for running on the 1st Sunday and last " \
+                    "Friday of a month. If left empty, will run on any weekday"
 SCHEDULE_RRULE = "A scheduling rule in the iCalendar format, e.g. " \
                  "'RRULE:FREQ=DAILY;INTERVAL=3', which means run every 3 " \
                  "days"
@@ -438,6 +453,15 @@ MANAGER = "Connect to a specific manager by IP or host"
 
 FROM_DATETIME = "Beginning of a period"
 TO_DATETIME = "End of a period"
+
+TIME_EXPRESSION = "{}. Supported formats: YYYY-MM-DD HH:MM, HH:MM, or a time" \
+                  " delta expression such as '+2 weeks' or '+1day+10min'. " \
+                  + TIME_UNITS
+TIMEZONE = "The timezone to be used for scheduling, e.g. 'EST' or " \
+           "'Asia/Jerusalem'. By default, the local timezone will be used. " \
+           "Supports any timezone in the tz database (" \
+           "en.wikipedia.org/wiki/List_of_tz_database_time_zones)"
+
 BEFORE = "How long ago did the specified period ended"
 KEEP_LAST = "Keep the N most recent {0} from deletion"
 
@@ -475,22 +499,58 @@ REEVALUATE_ACTIVE_STATUSES_PLUGINS = REEVALUATE_ACTIVE_STATUSES + "  This " \
                                      "deployment update flows and has " \
                                      "a similar effect on those."
 
-LABELS = "A labels list of the form <key>:<value>,<key>:<value>"
+LABELS = "A labels list of the form <key>:<value>,<key>:<value>. " \
+         "Any comma and colon in <value> must be escaped with `\\`. " \
+         "The labels' keys are saved in lowercase."
 
-_FILTER_RULES_FORMS = 'Filter rules must be one of: <key>=<value>, ' \
-                      '<key>=[<value1>,<value2>,...], <key>!=<value>, ' \
-                      '<key>!=[<value1>,<value2>,...], <key> is null, ' \
-                      '<key> is not null. E.g. "a=b and c!=[d,e] and ' \
-                      'f is not null". The filter rules will be saved in ' \
-                      'lower case.'
+LABELS_FILTER_RULES = "A labels' filter rule. Labels' filter rules must be " \
+                      "one of: <key>=<value>, <key>!=<value>, " \
+                      "<key> is-not <value>, <key> is null, " \
+                      "<key> is not null. <value> can be a single string or " \
+                      "a list of strings of the form " \
+                      "[<value1>,<value2>,...]. Any comma and " \
+                      "colon in <value> must be escaped with `\\`. " \
+                      "The labels' keys specified in the filter rules will " \
+                      "be saved in lower case."
 
-FILTER_RULES = 'List of filter rules separated with "and". ' + \
-               _FILTER_RULES_FORMS
+ATTRS_FILTER_RULES = "An attributes' filter rule. Attributes' filter rules " \
+                     "must be one of: <key>=<value>, <key>!=<value>, " \
+                     "<key> contains <value>, " \
+                     "<key> does-not-contain <value>, " \
+                     "<key> starts-with <value>, <key> ends-with <value>, " \
+                     "<key> is not empty. <value> can be a single string or " \
+                     "a list of strings of the form [<value1>,<value2>,...]." \
+                     " Allowed attributes to filter by are: "
 
-FILTER_RULES_OR_ID = 'A filter ID or a list of filter rules separated with ' \
-                     '"and". ' + _FILTER_RULES_FORMS
+DEPLOYMENTS_ATTRS_FILTER_RULES = ATTRS_FILTER_RULES + \
+                                 '[blueprint_id, created_by, site_name, ' \
+                                 'schedules]. This argument can be used ' \
+                                 'multiple times'
 
+BLUEPRINTS_ATTRS_FILTER_RULES = ATTRS_FILTER_RULES + \
+                                '[created_by]. This argument can be ' \
+                                'used multiple times'
+
+FILTER_ID = 'Filter results according to the specified filter'
+
+DEP_GROUP_ID = 'Deployment group id (a name).'
 DEP_GROUP_BLUEPRINT = 'Default blueprint for this deployment group'
 DEP_GROUP_DESCRIPTION = 'Description of this deployment group'
 DEP_GROUP_DEP_ID = 'Deployment ID to add or remove from the group'
 DEP_GROUP_COUNT = 'Create this many deployments in the group'
+DEP_GROUP_FILTER_ID = 'Use deployments selected by this filter'
+DEP_GROUP_FROM_GROUP = 'Use deployments belonging to this group'
+DEP_GROUP_INTO_ENVIRONMENTS = 'Add created deployments to the environments ' \
+                              'already existing in this group.'
+GROUP_ID_FILTER = 'Show only results belonging to this group'
+DELETE_GROUP_DEPLOYMENTS = 'Delete all deployments belonging to this group'
+
+GENERATE_ID = 'Generate a UUID to serve as the deployment ID. This flag ' \
+              'cannot be provided if a deployment ID is specified'
+
+DISPLAY_NAME = 'The display name of the deployment. If not specified, ' \
+               'the deployment ID will be used instead.'
+
+SEARCH_NAME = 'Search deployments by their display name. The returned list ' \
+              'will include only deployments that contain the given search ' \
+              'pattern'
