@@ -25,6 +25,7 @@ from dsl_parser.exceptions import DSLParsingException
 from cloudify._compat import urlparse
 from cloudify_rest_client.constants import VISIBILITY_EXCEPT_PRIVATE
 
+from .. import env
 from .. import local
 from .. import utils
 from ..cli import cfy, helptexts
@@ -34,9 +35,12 @@ from ..config import config
 from ..logger import get_global_json_output
 from ..table import print_data, print_single
 from ..exceptions import CloudifyCliError
-from ..utils import (prettify_client_error,
-                     get_visibility,
-                     validate_visibility)
+from ..utils import prettify_client_error, get_visibility, validate_visibility
+from ..labels_utils import (add_labels,
+                            delete_labels,
+                            list_labels,
+                            modify_resource_labels)
+from .. import filters_utils
 from .summary import BASE_SUMMARY_FIELDS, structure_summary_results
 
 
@@ -44,7 +48,7 @@ DESCRIPTION_LIMIT = 20
 BASE_BLUEPRINT_COLUMNS = ['id', 'description', 'main_file_name', 'created_at']
 BLUEPRINT_COLUMNS = BASE_BLUEPRINT_COLUMNS + ['updated_at', 'visibility',
                                               'tenant_name', 'created_by',
-                                              'state', 'error']
+                                              'state', 'error', 'labels']
 INPUTS_COLUMNS = ['name', 'type', 'default', 'description']
 BLUEPRINTS_SUMMARY_FIELDS = BASE_SUMMARY_FIELDS
 
@@ -86,6 +90,7 @@ def validate_blueprint(blueprint_path, logger):
 @cfy.options.blueprint_id(validate=True)
 @cfy.options.blueprint_filename()
 @cfy.options.async_upload
+@cfy.options.labels
 @cfy.options.validate
 @cfy.options.common_options
 @cfy.options.tenant_name(required=False, resource_name_for_help='blueprint')
@@ -100,6 +105,7 @@ def upload(ctx,
            blueprint_id,
            blueprint_filename,
            async_upload,
+           labels,
            validate,
            private_resource,
            visibility,
@@ -114,6 +120,7 @@ def upload(ctx,
     retrieved from GitHub).
     Supported archive types are: zip, tar, tar.gz and tar.bz2
     """
+    client.license.check()
     utils.explicit_tenant_name_message(tenant_name, logger)
     processed_blueprint_path = blueprint.get(
         blueprint_path, blueprint_filename)
@@ -145,7 +152,8 @@ def upload(ctx,
             blueprint_filename,
             visibility,
             progress_handler,
-            async_upload=True
+            async_upload=True,
+            labels=labels
         )
     else:
         try:
@@ -165,7 +173,8 @@ def upload(ctx,
                 progress_handler,
                 # if blueprint is in an archive we skip the size limit check
                 utils.is_archive(blueprint_path),
-                async_upload=True
+                async_upload=True,
+                labels=labels
             )
         finally:
             # When an archive file is passed, it's extracted to a temporary
@@ -232,6 +241,8 @@ def delete(blueprint_id, force, logger, client, tenant_name):
 
 
 @cfy.command(name='list', short_help='List blueprints')
+@cfy.options.filter_id
+@cfy.options.blueprint_filter_rules
 @cfy.options.sort_by()
 @cfy.options.descending
 @cfy.options.common_options
@@ -244,7 +255,9 @@ def delete(blueprint_id, force, logger, client, tenant_name):
 @cfy.assert_manager_active()
 @cfy.pass_client()
 @cfy.pass_logger
-def manager_list(sort_by,
+def manager_list(filter_id,
+                 filter_rules,
+                 sort_by,
                  descending,
                  tenant_name,
                  all_tenants,
@@ -266,18 +279,29 @@ def manager_list(sort_by,
 
     utils.explicit_tenant_name_message(tenant_name, logger)
     logger.info('Listing all blueprints...')
+
     blueprints_list = client.blueprints.list(
         sort=sort_by,
         is_descending=descending,
         _all_tenants=all_tenants,
         _search=search,
         _offset=pagination_offset,
-        _size=pagination_size
+        _size=pagination_size,
+        filter_rules=filter_rules,
+        filter_id=filter_id
     )
     blueprints = [trim_description(b) for b in blueprints_list]
+    modify_resource_labels(blueprints)
     print_data(BLUEPRINT_COLUMNS, blueprints, 'Blueprints:')
+
     total = blueprints_list.metadata.pagination.total
-    logger.info('Showing {0} of {1} blueprints'.format(len(blueprints), total))
+    base_str = 'Showing {0} of {1} blueprints'.format(
+        len(blueprints_list), total)
+    if filter_rules or filter_id:
+        filtered = blueprints_list.metadata.get('filtered')
+        if filtered is not None:
+            base_str += ' ({} hidden by filter)'.format(filtered)
+    logger.info(base_str)
 
 
 @cfy.command(name='list', short_help='List blueprints')
@@ -520,3 +544,212 @@ def summary(target_field, sub_field, logger, client, tenant_name,
         items,
         'Blueprint summary by {field}'.format(field=target_field),
     )
+
+
+@blueprints.group(name='labels',
+                  short_help="Handle a blueprint's labels")
+@cfy.options.common_options
+def labels():
+    if not env.is_initialized():
+        env.raise_uninitialized()
+
+
+@labels.command(name='list',
+                short_help="List the labels of a specific blueprint")
+@cfy.argument('blueprint-id')
+@cfy.options.tenant_name(required=False, resource_name_for_help='blueprint')
+@cfy.options.common_options
+@cfy.assert_manager_active()
+@cfy.pass_client()
+@cfy.pass_logger
+def list_blueprint_labels(blueprint_id,
+                          logger,
+                          client,
+                          tenant_name):
+    list_labels(blueprint_id, 'blueprint', client.blueprints,
+                logger, tenant_name)
+
+
+@labels.command(name='add',
+                short_help="Add labels to a specific blueprint")
+@cfy.argument('labels-list',
+              callback=cfy.parse_and_validate_labels)
+@cfy.argument('blueprint-id')
+@cfy.options.tenant_name(required=False, resource_name_for_help='blueprint')
+@cfy.options.common_options
+@cfy.assert_manager_active()
+@cfy.pass_client()
+@cfy.pass_logger
+def add_blueprint_labels(labels_list,
+                         blueprint_id,
+                         logger,
+                         client,
+                         tenant_name):
+    """LABELS_LIST: <key>:<value>,<key>:<value>.
+    Any comma and colon in <value> must be escaped with '\\'."""
+    add_labels(blueprint_id, 'blueprint', client.blueprints, labels_list,
+               logger, tenant_name)
+
+
+@labels.command(name='delete',
+                short_help="Delete labels from a specific blueprint")
+@cfy.argument('label', callback=cfy.parse_and_validate_label_to_delete)
+@cfy.argument('blueprint-id')
+@cfy.options.tenant_name(required=False, resource_name_for_help='blueprint')
+@cfy.options.common_options
+@cfy.assert_manager_active()
+@cfy.pass_client()
+@cfy.pass_logger
+def delete_blueprint_labels(label,
+                            blueprint_id,
+                            logger,
+                            client,
+                            tenant_name):
+    """
+    LABEL: A mixed list of labels and keys, i.e.
+    <key>:<value>,<key>,<key>:<value>. If <key> is provided,
+    all labels associated with this key will be deleted from the deployment.
+    Any comma and colon in <value> must be escaped with `\\`
+    """
+    delete_labels(blueprint_id, 'blueprint', client.blueprints, label,
+                  logger, tenant_name)
+
+
+@blueprints.group(name='filters',
+                  short_help="Handle the blueprints' filters")
+@cfy.options.common_options
+def filters():
+    if not env.is_initialized():
+        env.raise_uninitialized()
+
+
+@filters.command(name='list',
+                 short_help="List all filters associated with blueprints")
+@cfy.options.sort_by('id')
+@cfy.options.descending
+@cfy.options.common_options
+@cfy.options.tenant_name_for_list(required=False,
+                                  resource_name_for_help='filter')
+@cfy.options.all_tenants
+@cfy.options.search
+@cfy.options.pagination_offset
+@cfy.options.pagination_size
+@cfy.assert_manager_active()
+@cfy.pass_client()
+@cfy.pass_logger
+def list_blueprints_filters(sort_by,
+                            descending,
+                            tenant_name,
+                            all_tenants,
+                            search,
+                            pagination_offset,
+                            pagination_size,
+                            logger,
+                            client):
+    """List all blueprints' filters"""
+    filters_utils.list_filters('blueprints',
+                               sort_by,
+                               descending,
+                               tenant_name,
+                               all_tenants,
+                               search,
+                               pagination_offset,
+                               pagination_size,
+                               logger,
+                               client.blueprints_filters)
+
+
+@filters.command(name='create', short_help="Create a new blueprints' filter")
+@cfy.argument('filter-id', callback=cfy.validate_name)
+@cfy.options.blueprint_filter_rules
+@cfy.options.visibility(mutually_exclusive_required=False)
+@cfy.options.tenant_name(required=False, resource_name_for_help='filter')
+@cfy.options.common_options
+@cfy.assert_manager_active()
+@cfy.pass_client(use_tenant_in_header=True)
+@cfy.pass_logger
+def create_blueprints_filter(filter_id,
+                             filter_rules,
+                             visibility,
+                             tenant_name,
+                             logger,
+                             client):
+    """Create a new blueprints' filter
+
+    `FILTER-ID` is the new filter's ID
+    """
+    filters_utils.create_filter('blueprints',
+                                filter_id,
+                                filter_rules,
+                                visibility,
+                                tenant_name,
+                                logger,
+                                client.blueprints_filters)
+
+
+@filters.command(name='get',
+                 short_help="Get details for a single blueprints' filter")
+@cfy.argument('filter-id', callback=cfy.validate_name)
+@cfy.options.tenant_name(required=False, resource_name_for_help='filter')
+@cfy.options.common_options
+@cfy.assert_manager_active()
+@cfy.pass_client(use_tenant_in_header=True)
+@cfy.pass_logger
+def get_blueprints_filter(filter_id, tenant_name, logger, client):
+    """Get details for a single blueprints' filter
+
+    `FILTER-ID` is the filter's ID
+    """
+    filters_utils.get_filter('blueprints',
+                             filter_id,
+                             tenant_name,
+                             logger,
+                             client.blueprints_filters)
+
+
+@filters.command(name='update',
+                 short_help="Update an existing blueprints' filter")
+@cfy.argument('filter-id', callback=cfy.validate_name)
+@cfy.options.blueprint_filter_rules
+@cfy.options.update_visibility
+@cfy.options.tenant_name(required=False, resource_name_for_help='filter')
+@cfy.options.common_options
+@cfy.assert_manager_active()
+@cfy.pass_client(use_tenant_in_header=True)
+@cfy.pass_logger
+def update_blueprints_filter(filter_id,
+                             filter_rules,
+                             visibility,
+                             tenant_name,
+                             logger,
+                             client):
+    """Update an existing blueprints' filter's filter rules or visibility
+
+    `FILTER-ID` is the filter's ID
+    """
+    filters_utils.update_filter('blueprints',
+                                filter_id,
+                                filter_rules,
+                                visibility,
+                                tenant_name,
+                                logger,
+                                client.blueprints_filters)
+
+
+@filters.command(name='delete', short_help="Delete a blueprints' filter")
+@cfy.argument('filter-id', callback=cfy.validate_name)
+@cfy.options.tenant_name(required=False, resource_name_for_help='filter')
+@cfy.options.common_options
+@cfy.assert_manager_active()
+@cfy.pass_client()
+@cfy.pass_logger
+def delete_deployments_filter(filter_id, tenant_name, logger, client):
+    """Delete a blueprints' filter
+
+    `FILTER-ID` is the filter's ID
+    """
+    filters_utils.delete_filter('blueprints',
+                                filter_id,
+                                tenant_name,
+                                logger,
+                                client.blueprints_filters)
