@@ -28,6 +28,7 @@ from ..cli import cfy, helptexts
 from ..logger import get_events_logger, get_global_json_output
 from ..constants import DEFAULT_UNINSTALL_WORKFLOW, CREATE_DEPLOYMENT
 from ..execution_events_fetcher import (
+    ExecutionEventsFetcher,
     wait_for_execution,
     wait_for_execution_group
 )
@@ -209,10 +210,16 @@ def manager_start(workflow_id,
     events_message = "* Run 'cfy events list {0}' to retrieve the " \
                      "execution's events/logs"
     original_timeout = timeout
-    logger.info('Executing workflow `{0}` on deployment `{1}`'
-                ' [timeout={2} seconds]'.format(workflow_id,
-                                                deployment_id,
-                                                timeout))
+
+    if schedule:
+        logger.info(
+            'Scheduling the execution of workflow `%s` on deployment `%s`. ',
+            workflow_id, deployment_id)
+    else:
+        logger.info('Executing workflow `{0}` on deployment `{1}`'
+                    ' [timeout={2} seconds]'.format(workflow_id,
+                                                    deployment_id,
+                                                    timeout))
     try:
         try:
             execution = client.executions.start(
@@ -265,7 +272,9 @@ def manager_start(workflow_id,
                         ' start when possible.')
             return
         if execution.status == 'scheduled':
-            logger.info('Execution is scheduled for {0}.'.format(schedule))
+            logger.info('Execution is scheduled for %s.\nYou can see the '
+                        'execution schedule using `cfy deployments schedule '
+                        'list`.', schedule)
             return
         execution = wait_for_execution(client,
                                        execution,
@@ -455,10 +464,11 @@ def local_start(workflow_id,
               default=None, required=False)
 @cfy.options.common_options
 @cfy.options.tenant_name(required=False, resource_name_for_help='summary')
+@cfy.options.group_id_filter
 @cfy.options.all_tenants
 @cfy.pass_logger
 @cfy.pass_client()
-def summary(target_field, sub_field, logger, client, tenant_name,
+def summary(target_field, sub_field, group_id, logger, client, tenant_name,
             all_tenants):
     """Retrieve summary of executions, e.g. a count of each execution with
     the same deployment ID.
@@ -473,6 +483,7 @@ def summary(target_field, sub_field, logger, client, tenant_name,
         _target_field=target_field,
         _sub_field=sub_field,
         _all_tenants=all_tenants,
+        execution_group_id=group_id,
     )
 
     columns, items = structure_summary_results(
@@ -546,7 +557,7 @@ def groups():
 def execution_groups_get(execution_group_id, client, logger):
     group = client.execution_groups.get(execution_group_id)
     print_single(
-        ['id', 'executions', 'workflow_id', 'deployment_group'],
+        ['id', 'workflow_id', 'deployment_group_id'],
         group,
         'Execution group {0}:'.format(execution_group_id)
     )
@@ -574,10 +585,53 @@ def execution_groups_list(client, logger):
     )
 
 
+@groups.command('details',
+                short_help='Details of an execution group [manager only]')
+@cfy.argument('execution_group_id')
+@cfy.options.common_options
+@cfy.pass_client()
+@cfy.pass_logger
+def execution_groups_details(execution_group_id, client, logger):
+    group = client.execution_groups.get(execution_group_id)
+    group.update({'#executions': len(group.get('execution_ids'))})
+    print_single(['workflow_id', 'deployment_group_id', '#executions',
+                  'created_at', 'status'],
+                 group,
+                 'Execution group {0}:'.format(execution_group_id))
+
+    # Let's find out the total number of events
+    events = client.events.list(
+        execution_group_id=execution_group_id,
+        include_logs=True, _size=1)
+    events_total = events.metadata.get('pagination', {}).get('total')
+    execution_events = ExecutionEventsFetcher(
+            client,
+            include_logs=True,
+            execution_group_id=execution_group_id
+    )
+    events_logger = get_events_logger(json_output=False)
+    pagination_size = 10 if events_total >= 10 else events_total
+    print_details(None, 'Last {0} logs:'.format(pagination_size))
+    execution_events.fetch_and_process_events_batch(
+        events_handler=events_logger,
+        offset=events_total - pagination_size,
+        size=pagination_size)
+
+    summary = client.summary.executions.get(
+        _target_field='status',
+        execution_group_id=execution_group_id,
+    )
+    print_details({s['status']: s['executions'] for s in summary},
+                  '\nExecutions\' status summary:')
+    logger.info('')
+
+
 @groups.command('start',
                 short_help='Execute a workflow on each deployment in a group')
 @click.option('--deployment-group', '-g',
               help='The deployment group ID to run the workflow on')
+@click.option('--concurrency', help='Run this many executions at a time',
+              type=int, default=5)
 @click.argument('workflow-id')
 @cfy.options.common_options
 @cfy.options.parameters
@@ -587,13 +641,127 @@ def execution_groups_list(client, logger):
 @cfy.pass_client()
 @cfy.pass_logger
 def execution_groups_start(deployment_group, workflow_id, parameters,
-                           json_output, force, timeout, client, logger):
+                           json_output, force, timeout, concurrency,
+                           client, logger):
     events_logger = get_events_logger(json_output)
     group = client.execution_groups.start(
         deployment_group_id=deployment_group,
         workflow_id=workflow_id,
         default_parameters=parameters,
-        force=force
+        force=force,
+        concurrency=concurrency,
     )
-    wait_for_execution_group(
-        client, group, events_handler=events_logger, timeout=timeout)
+    logger.info('Execution group %s started: running %s on '
+                'deployment group %s [concurrency=%s]',
+                group.id, group.workflow_id, group.deployment_group_id,
+                group.concurrency)
+    try:
+        execution = wait_for_execution_group(client, group,
+                                             events_handler=events_logger,
+                                             include_logs=True,
+                                             timeout=timeout,
+                                             logger=logger)
+        logger.info("Finished executing workflow {0} on deployment group "
+                    "{1}.\n\n"
+                    "* Run 'cfy events list -g {2}' to retrieve the "
+                    "execution group's events/logs".format(
+                        workflow_id, deployment_group, execution.id)
+                    )
+
+    except ExecutionTimeoutError as e:
+        logger.info("Timed out waiting for workflow '{0}' on deployment group "
+                    "'{1}' to end. The execution group may still be running, "
+                    "however, the command-line utility was instructed to wait "
+                    "up to {3} seconds for its completion.\n\n"
+                    "* Run 'cfy executions groups cancel {2}' to cancel the "
+                    "running workflow.\n"
+                    "* Run 'cfy events list -g {2} --tail' to retrieve the "
+                    "execution group's events/logs".format(
+                        workflow_id, deployment_group, e.execution_id, timeout)
+                    )
+        raise SuppressedCloudifyCliError()
+
+
+@groups.command('cancel', short_help='Cancel an execution group')
+@cfy.argument('group-id')
+@cfy.options.force(help=helptexts.FORCE_CANCEL_EXECUTION)
+@cfy.options.kill()
+@cfy.options.tenant_name(
+    required=False, resource_name_for_help='execution group')
+@cfy.options.common_options
+@cfy.pass_client()
+@cfy.pass_logger
+def execution_groups_cancel(group_id, force, kill,
+                            client, logger, tenant_name):
+    utils.explicit_tenant_name_message(tenant_name, logger)
+    if kill:
+        message = 'Killing'
+    elif force:
+        message = 'Force-cancelling'
+    else:
+        message = 'Cancelling'
+    logger.info('%s execution group %s', message, group_id)
+    client.execution_groups.cancel(group_id, force=force, kill=kill)
+    logger.info("A cancel request for group %s has been sent", group_id)
+
+
+@groups.command('resume', short_help='Resume an execution group')
+@cfy.argument('group-id')
+@cfy.options.reset_operations
+@cfy.options.tenant_name(
+    required=False, resource_name_for_help='execution group')
+@cfy.options.common_options
+@cfy.pass_client()
+@cfy.pass_logger
+def execution_groups_resume(group_id, reset_operations,
+                            client, logger, tenant_name):
+    utils.explicit_tenant_name_message(tenant_name, logger)
+    logger.info('Resuming execution group %s', group_id)
+    client.execution_groups.resume(group_id, force=reset_operations)
+    logger.info("A resume request for group %s has been sent", group_id)
+
+
+@groups.command('set-success-group',
+                short_help='Set a target group for successful deployments')
+@cfy.argument('group-id')
+@cfy.argument('success-group-id')
+@cfy.options.tenant_name(
+    required=False, resource_name_for_help='execution group')
+@cfy.options.common_options
+@cfy.pass_client()
+@cfy.pass_logger
+def execution_groups_set_success(group_id, success_group_id,
+                                 client, logger, tenant_name):
+    """Set success target group for this execution-group.
+
+    Deployments for which the execution succeeds, will be added to the
+    success target deployments group.
+    """
+    utils.explicit_tenant_name_message(tenant_name, logger)
+    client.execution_groups.set_target_group(
+        group_id, success_group=success_group_id)
+    logger.info('Execution group %s: success target group set to %s',
+                group_id, success_group_id)
+
+
+@groups.command('set-failure-group',
+                short_help='Set a target group for failed deployments')
+@cfy.argument('group-id')
+@cfy.argument('failure-group-id')
+@cfy.options.tenant_name(
+    required=False, resource_name_for_help='execution group')
+@cfy.options.common_options
+@cfy.pass_client()
+@cfy.pass_logger
+def execution_groups_set_failure(group_id, failure_group_id,
+                                 client, logger, tenant_name):
+    """Set success target group for this execution-group.
+
+    Deployments for which the execution succeeds, will be added to the
+    success target deployments group.
+    """
+    utils.explicit_tenant_name_message(tenant_name, logger)
+    client.execution_groups.set_target_group(
+        group_id, failed_group=failure_group_id)
+    logger.info('Execution group %s: success target group set to %s',
+                group_id, failure_group_id)
