@@ -505,7 +505,7 @@ class ProfileContext(object):
         workdir = destination or self.workdir
         # Create a new file
         if not os.path.exists(workdir):
-            os.makedirs(workdir)
+            os.makedirs(workdir, mode=0o700)
         target_file_path = os.path.join(
             workdir,
             'context.json')
@@ -605,6 +605,9 @@ class ClusterHTTPClient(HTTPClient):
                 CloudifyClientError) as e:
             if isinstance(e, CloudifyClientError) and e.status_code != 502:
                 raise
+            self.logger.warning('Could not connect to manager %s on port %s',
+                                self.host, self.port)
+            self.logger.debug(str(e))
         return _TRY_NEXT_NODE
 
     def _use_node(self, node):
