@@ -23,6 +23,7 @@ from .commands import ldap
 from .commands import users
 from .commands import nodes
 from .commands import sites
+from .commands import apply
 from .commands import agents
 from .commands import events
 from .commands import groups
@@ -32,7 +33,6 @@ from .commands import config
 from .commands import cluster
 from .commands import install
 from .commands import plugins
-from .commands import filters
 from .commands import tenants
 from .commands import secrets
 from .commands import license
@@ -108,7 +108,7 @@ def _register_commands():
     _cfy.add_command(license.license)
     _cfy.add_command(sites.sites)
     _cfy.add_command(certificates.certificates)
-    _cfy.add_command(filters.filters)
+    _cfy.add_command(apply.apply)
 
     deployments.deployments.add_command(deployments.manager_create)
     deployments.deployments.add_command(deployments.manager_delete)
